@@ -188,7 +188,33 @@ class FlowPrint(object):
         # Return result
         return result
 
-    def recognize(self, X, y=None):
+    def fit_predict(self, X, y=None, default='common'):
+        """Fit FlowPrint with samples and labels and return the predictions
+            of the same samples after running them through FlowPrint.
+
+            Parameters
+            ----------
+            X : np.array of shape=(n_samples,)
+                Flows for fitting FlowPrint.
+
+            y : np.array of shape=(n_samples,), optional
+                If given, attach labels to fingerprints from X.
+
+            default : 'common'|'largest'|other, default='common'
+                Default to this strategy if no match is found
+                 - 'common' : return the fingerprint with most flows
+                 - 'largest': return the largest fingerprint
+                 - other: return <other> as match, e.g. Fingerprint()/None
+
+            Returns
+            -------
+            result : np.array of shape=(n_fingerprints,)
+                Closest matching fingerprints to original.
+                If no match is found, fall back on default
+            """
+        return self.fit(X, y).predict(X, y, default)
+
+    def recognize(self, X, y=None, default='common'):
         """Return labels corresponding to closest matching fingerprints
 
             Parameters
@@ -198,13 +224,20 @@ class FlowPrint(object):
 
             y : ignored
 
+            default : 'common'|'largest'|other, default='common'
+                Default to this strategy if no match is found
+                 - 'common' : return the fingerprint with most flows
+                 - 'largest': return the largest fingerprint
+                 - other: return <other> as match, e.g. Fingerprint()/None
+
             Returns
             -------
             result : np.array of shape=(n_fingerprints,)
                 Label of closest matching fingerprints to original
             """
         # Perform predict and return corresponding fingerprints
-        return np.asarray([self.fingerprints.get(x) for x in self.predict(X)])
+        return np.asarray([self.fingerprints.get(x) for x in
+                           self.predict(X, default=default)])
 
 
     def detect(self, X, y=None, threshold=None):
@@ -237,13 +270,13 @@ class FlowPrint(object):
     #                             I/O methods                              #
     ########################################################################
 
-    def store(self, file, fingerprints=None):
-        """Store fingerprints to file.
+    def save(self, file, fingerprints=None):
+        """Save fingerprints to file.
 
             Parameters
             ----------
             file : string
-                File in which to store flowprint fingerprints.
+                File in which to save flowprint fingerprints.
 
             fingerprints : iterable of Fingerprint (optional)
                 If None export fingerprints from fitted FlowPrint object,
